@@ -1226,7 +1226,7 @@ int ffiter(int n_cols,
     long rept, rowrept, width, tnull, naxes[9] = {1,1,1,1,1,1,1,1,1}, groups;
     double zeros = 0.;
     char message[FLEN_ERRMSG], keyname[FLEN_KEYWORD], nullstr[FLEN_VALUE];
-    char **stringptr, *nullptr, *cptr;
+    char **stringptr, *nullpointer, *cptr;
 
     if (*status > 0)
         return(*status);
@@ -2081,24 +2081,24 @@ int ffiter(int n_cols,
           {
             stringptr = cols[jj].array;
             dataptr = stringptr + 1;
-            nullptr = *stringptr;
+            nullpointer = *stringptr;
             nbytes = 2;
           }
           else
           {
             dataptr = (char *) cols[jj].array + col[jj].nullsize;
-            nullptr = (char *) cols[jj].array;
+            nullpointer = (char *) cols[jj].array;
             nbytes = col[jj].nullsize;
           }
 
-          if (memcmp(nullptr, &zeros, nbytes) ) 
+          if (memcmp(nullpointer, &zeros, nbytes) ) 
           {
             /* null value flag not zero; must check for and write nulls */
             if (hdutype == IMAGE_HDU)   
             {
                 if (ffppn(cols[jj].fptr, cols[jj].datatype, 
                       felement, cols[jj].repeat * ntodo, dataptr,
-                      nullptr, &tstatus) > 0)
+                      nullpointer, &tstatus) > 0)
                 break;
             }
             else
@@ -2113,7 +2113,7 @@ int ffiter(int n_cols,
 
                 if (ffpcn(cols[jj].fptr, cols[jj].datatype, cols[jj].colnum, frow,
                       felement, cols[jj].repeat * ntodo, dataptr,
-                      nullptr, &tstatus) > 0)
+                      nullpointer, &tstatus) > 0)
                 break;
             }
           }
